@@ -4,9 +4,9 @@ rescaledDensities <- function(y, a, b, densFunction, probFunction, ...) {
     yes  = 0,
     no   = densFunction(y, ...)
   )
-  F.a <- ifelse(a == 0, 0, probFunction(a, ...))
+  F.a <- tryCatch(probFunction(a, ...), error = function(e) 0)
   F.b <- ifelse(is.infinite(b), 1, probFunction(b, ...))
   dens <- dens / (F.b - F.a)
   attributes(dens) <- attributes(y)
-  return(dens)
+  dens
 }
